@@ -1,6 +1,8 @@
 #include <botan/hash.h>
 #include <trantor/utils/Utilities.h>
 
+#include <cassert>
+
 namespace trantor
 {
 namespace utils
@@ -36,6 +38,7 @@ Hash256 sha3(const void* data, size_t len)
 {
     Hash256 hash;
     auto sha3 = Botan::HashFunction::create("SHA-3(256)");
+    assert(sha3 != nullptr);
     sha3->update((const unsigned char*)data, len);
     sha3->final((unsigned char*)&hash);
     return hash;
@@ -45,6 +48,7 @@ Hash256 blake2b(const void* data, size_t len)
 {
     Hash256 hash;
     auto blake2b = Botan::HashFunction::create("BLAKE2b(256)");
+    assert(blake2b != nullptr);
     blake2b->update((const unsigned char*)data, len);
     blake2b->final((unsigned char*)&hash);
     return hash;
